import re

__all__ = ['run']

MODULE_RE = re.compile(r'^(\w+)(?=\.)|(?<![.\w])(\w+)(?=\.)')

def get_modules(s):
    """
    Extracts the module from a given command. E.g.:
        'string.digits' -> 'string'
        'print(3)' -> None
    """
    return [x or y for x,y in re.findall(MODULE_RE,s)]

def run(*args, silent=False):
    # get all (unique) modules
    instructions = list(args)
    modules = set(module for mods in map(get_modules,instructions) for module in mods)

    globs = { module:__import__(module) for module in modules } 

    if not silent:
        instructions[-1] = 'print({})'.format(instructions[-1])

    src = ';'.join(instructions)
    cmd = compile(src,'cmd','exec')
    exec(cmd,globs)


import sys
from . import run, __version__

HELP = """
usage: prynt [options] command
    -h  --help         print this usage and exit
    -v  --version      print version and exit
    -s  --silent       do not print output
"""

OPTIONS_DICT = {
    '--silent': 'silent',
    's': 'silent',

    'h': 'help',
    '--help': 'help',

    '--version': 'version',
    'v': 'version'
}

def get_options(args):
    opts = {}

    for a in args:
        if a[0] != '-':
            continue

        if a.startswith('--'):
            opts[OPTIONS_DICT[a]] = True
        else:
            # a ~ '-xyz'
            for opt in a[1:]:
                opts[OPTIONS_DICT[opt]] = True
    
    return opts

def main():
    if len(sys.argv) < 2:
        print(HELP)
        return

    options = get_options(sys.argv[1:])

    if 'help' in options:
        print(HELP)
        return
    if 'version' in options:
        print(__version__)
        return

    parameters = sys.argv[-1]
    # Separate command in structions
    instructions = parameters.split(';')

    # verbose by default
    run(*instructions, **options)

if __name__ == '__main__':
    main()



from setuptools import setup, find_packages
from distutils.util import convert_path

with open("README.md", "r") as fh:
    long_description = fh.read()

main_ns = {}
ver_path = convert_path('prynter/version.py')
with open(ver_path) as ver_file:
    exec(ver_file.read(), main_ns)

setup(
    name="prynter",
    version=main_ns['__version__'],
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Iván Canales",
    author_email="kanales.contact@gmail.com",
    description="Small utility to execute short python commands",
    url="https://github.com/kanales/prynter",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    entry_points={
        'console_scripts': [
            'prynt = prynter.__main__:main'
        ]
    }
)
